@@ -10,6 +10,7 @@
 #'  Are missing values allowed? Default is \code{TRUE}.
 #' @param d [\code{integer(1)}]\cr
 #'  Dimensionality of array.
+#'  Default is \code{NULL} (no check).
 #' @family basetypes
 #' @useDynLib checkmate c_check_array
 #' @export
@@ -23,16 +24,13 @@ checkArray = function(x, mode = NULL, any.missing = TRUE, d = NULL) {
 #' @useDynLib checkmate c_check_array
 #' @export
 assertArray = function(x, mode = NULL, any.missing = TRUE, d = NULL, .var.name) {
-  makeAssertion(
-    .Call("c_check_array", x, mode, any.missing, d, PACKAGE = "checkmate")
-  , vname(x, .var.name))
+  res = .Call("c_check_array", x, mode, any.missing, d, PACKAGE = "checkmate")
+  makeAssertion(res, vname(x, .var.name))
 }
 
 #' @rdname checkArray
 #' @useDynLib checkmate c_check_array
 #' @export
 testArray = function(x, mode = NULL, any.missing = TRUE, d = NULL) {
-  isTRUE(
-    .Call("c_check_array", x, mode, any.missing, d, PACKAGE = "checkmate")
-  )
+  isTRUE(.Call("c_check_array", x, mode, any.missing, d, PACKAGE = "checkmate"))
 }
