@@ -26,18 +26,6 @@ checkCharacter = function(x, min.chars = NULL, pattern = NULL, fixed = FALSE, ig
   checkCharacterProps(x, pattern, fixed, ignore.case)
 }
 
-checkCharacterProps = function(x, pattern = NULL, fixed = FALSE, ignore.case = FALSE) {
-  if (!is.null(pattern)) {
-    qassert(pattern, "S1")
-    qassert(fixed, "B1")
-    qassert(ignore.case, "B1")
-    ok = grepl(pattern, x, fixed = fixed, ignore.case = ignore.case)
-    if(!all(ok))
-      return(sprintf("Must comply to pattern '%s", pattern))
-  }
-  return(TRUE)
-}
-
 #' @rdname checkCharacter
 #' @useDynLib checkmate c_check_character
 #' @export
@@ -52,8 +40,18 @@ assertCharacter = function(x, min.chars = NULL, pattern = NULL, fixed = FALSE, i
 #' @useDynLib checkmate c_check_character
 #' @export
 testCharacter = function(x, min.chars = NULL, pattern = NULL, fixed = FALSE, ignore.case = FALSE, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL,  unique = FALSE, names = NULL) {
-  isTRUE(
-    .Call("c_check_character", x, min.chars, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate") %and%
-    checkCharacterProps(x, pattern, fixed, ignore.case)
-  )
+  isTRUE(.Call("c_check_character", x, min.chars, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")) &&
+  isTRUE(checkCharacterProps(x, pattern, fixed, ignore.case))
+}
+
+checkCharacterProps = function(x, pattern = NULL, fixed = FALSE, ignore.case = FALSE) {
+  if (!is.null(pattern)) {
+    qassert(pattern, "S1")
+    qassert(fixed, "B1")
+    qassert(ignore.case, "B1")
+    ok = grepl(pattern, x, fixed = fixed, ignore.case = ignore.case)
+    if(!all(ok))
+      return(sprintf("Must comply to pattern '%s", pattern))
+  }
+  return(TRUE)
 }
