@@ -29,7 +29,5 @@ assertFlag = function(x, na.ok = FALSE, .var.name) {
 #' @useDynLib checkmate c_check_flag
 #' @export
 testFlag = function(x, na.ok = FALSE) {
-  isTRUE(
-    .Call("c_check_flag", x, na.ok, PACKAGE = "checkmate")
-  )
+  isTRUE(.Call("c_check_flag", x, na.ok, PACKAGE = "checkmate"))
 }
