@@ -3,7 +3,9 @@
 #' @templateVar fn Function
 #' @template checker
 #' @param args [\code{character}]\cr
-#'  Expected formal arguments.
+#'  Expected formal arguments. Checks that a function has no arguments if
+#'  set to \code{character(0)}.
+#'  Default is \code{NULL} (no check).
 #' @param ordered [\code{logical(1)}]\cr
 #'  Flag whether the arguments provided in \code{args} must be the first
 #'  \code{length(args)} arguments of the function in the specified order.
@@ -15,7 +17,7 @@
 #'  testFunction(mean, args = "x")
 checkFunction = function(x, args = NULL, ordered = FALSE) {
   qassert(ordered, "B1")
-  x = try(match.fun(x), silent=TRUE)
+  x = try(match.fun(x), silent = TRUE)
   if (inherits(x, "try-error"))
     return("Function not found")
 
@@ -25,6 +27,12 @@ checkFunction = function(x, args = NULL, ordered = FALSE) {
     if (is.null(fargs))
       fargs = character(0L)
 
+    if (length(args) == 0L) {
+      if (length(fargs) > 0L)
+        return("May not have any arguments")
+      return(TRUE)
+    }
+
     if (ordered) {
       if (any(args != head(fargs, length(args)))) {
         return(sprintf("Must have first formal arguments (ordered): %s", collapse(args)))
@@ -41,7 +49,8 @@ checkFunction = function(x, args = NULL, ordered = FALSE) {
 #' @rdname checkFunction
 #' @export
 assertFunction = function(x, args = NULL, ordered = FALSE, .var.name) {
-  makeAssertion(checkFunction(x, args, ordered), vname(x, .var.name))
+  res = checkFunction(x, args, ordered)
+  makeAssertion(res, vname(x, .var.name))
 }
 
 #' @rdname checkFunction
