@@ -26,7 +26,5 @@ assertLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL,
 #' @useDynLib checkmate c_check_logical
 #' @export
 testLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL) {
-  isTRUE(
-    .Call("c_check_logical", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
-  )
+  isTRUE(.Call("c_check_logical", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate"))
 }
