@@ -7,6 +7,7 @@
 #'  \dQuote{unnamed} checks \code{x} to be unnamed.
 #'  \dQuote{named} (default) checks \code{x} to be named, this includes names to be not \code{NA} or emtpy (\code{""}).
 #'  \dQuote{unique} additionally tests for non-duplicated names.
+#'  \dQuote{strict} checks for unique names which comply to R's variable name restrictions.
 #'  Note that for zero-length \code{x} every name check evalutes to \code{TRUE}.
 #' @useDynLib checkmate c_check_named
 #' @export
@@ -31,7 +32,5 @@ assertNamed = function(x, type = "named", .var.name) {
 #' @useDynLib checkmate c_check_named
 #' @export
 testNamed = function(x, type = "named") {
-  isTRUE(
-    .Call("c_check_named", x, type, PACKAGE = "checkmate")
-  )
+  isTRUE(.Call("c_check_named", x, type, PACKAGE = "checkmate"))
 }
