@@ -24,7 +24,5 @@ assertScalar = function(x, na.ok = FALSE, .var.name) {
 #' @rdname checkScalar
 #' @export
 testScalar = function(x, na.ok = FALSE) {
-  isTRUE(
-    .Call("c_check_scalar", x, na.ok, PACKAGE = "checkmate")
-  )
+  isTRUE(.Call("c_check_scalar", x, na.ok, PACKAGE = "checkmate"))
 }
